Automated Tailwind CSS integration for Django 🐍💚💙 
---


This [django-tailwindcss-automated](https://pypi.org/project/django-tailwindcss-automated/) project aims to speed up the setup process of the TailwindCSS  within a Django project.



## Requirements

Before you dive in, make sure you have the following installed on your computer:

- [Node.js](https://nodejs.org/en/learn/getting-started/how-to-install-nodejs)
- [Git](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git)
- [Python](https://phoenixnap.com/kb/how-to-install-python-3-windows)



## Create a folder for your Django project.

- Open your file explorer or terminal and create a folder for your Django project. You can do this by navigating to the directory where you want to create the folder and using the mkdir command (if you're using a terminal) or by right-clicking and selecting "New Folder" in your file explorer.


![window screenshot](https://dev-to-uploads.s3.amazonaws.com/uploads/articles/eeu8hf0ss9zr9mtf8xty.png)



## Open VSCode

- In VSCode, go to "File" > "Open Folder..." and navigate to the folder you created {your_project_name}. Select the folder and click "Open".


![Open Folder screenshot](https://dev-to-uploads.s3.amazonaws.com/uploads/articles/nfoz0eiqf63dfpqjfwgq.png)


## Install the Package

- Open your terminal and install the package using pip.

```
pip install django_tailwindcss_automated
```



## Run the Script

- In your terminal, run the following script to automate the setup.

```
automate
```

## Start the Development Server

- Open another terminal and navigate to the {your_project_name} directory within your project folder

```
cd {your_project_name}
```


## Then start the development server

```
python manage.py runserver
```
---

## Happy Coding!!

![Screenshot](https://dev-to-uploads.s3.amazonaws.com/uploads/articles/7m7r8r962fu5ca3kvz9v.png)
